@@ -1,5 +1,5 @@
 mod parse;
 mod state;
 
-pub(crate) use parse::parse;
+pub use parse::parse;
 pub use parse::ParseGetResponseError;
